@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Convert notes and chords to Roman numeral notation
 
-our $VERSION = '0.1401';
+our $VERSION = '0.1500';
 
 use List::MoreUtils qw/ any first_index /;
 use Moo;
@@ -85,7 +85,7 @@ sub parse {
     print "NOTES: @notes\n" if $self->verbose;
 
     # Convert a diminished chord
-    $chord =~ s/(?:dim|ø)/o/;
+    $chord =~ s/dim/o/;
 
     # Get just the note part of the chord name
     ( my $note = $chord ) =~ s/^($note_re).*$/$1/;
@@ -107,7 +107,7 @@ sub parse {
     ( my $decorator = $chord ) =~ s/^(?:$note_re)(.*)$/$1/;
 
     # Are we minor or diminished?
-    my $minor = $decorator =~ /[-mo]/ ? 1 : 0;
+    my $minor = $decorator =~ /[-moø]/ ? 1 : 0;
     print "CHORD: $chord, NOTE: $note, ACCI: $accidental, DECO: $decorator, MINOR: $minor, POSN: $position\n" if $self->verbose;
 
     # Convert the case of the roman representation based on minor or major
@@ -130,6 +130,9 @@ sub parse {
     elsif ( $decorator =~ /△/ ) {
         $decorator =~ s/△/maj/;
     }
+    elsif ( $decorator =~ /ø/ ) {
+        $decorator =~ s/ø/7b5/;
+    }
     else {
         # Drop the minor and major part of the chord name
         $decorator =~ s/[-Mm]//i;
@@ -287,7 +290,7 @@ Music::ToRoman - Convert notes and chords to Roman numeral notation
 
 =head1 VERSION
 
-version 0.1401
+version 0.1500
 
 =head1 SYNOPSIS
 
@@ -300,20 +303,21 @@ version 0.1401
 
   my $roman = $mtr->parse('Am');  # i (minor)
   $roman = $mtr->parse('Bdim');   # iio (diminished)
-  $roman = $mtr->parse('B dim');  # ii o "
-  $roman = $mtr->parse('Bo');     # iio "
-  $roman = $mtr->parse('Bø');     # iio "
+  $roman = $mtr->parse('B dim');  # ii o
+  $roman = $mtr->parse('Bo');     # iio
+  $roman = $mtr->parse('Bø');     # ii7b5 (half-diminished)
   $roman = $mtr->parse('Bb');     # bII (flat-two major)
   $roman = $mtr->parse('CM');     # III (major)
-  $roman = $mtr->parse('C');      # III "
-  $roman = $mtr->parse('Cm9/G');  # iii9/VII (minor ninth with seven bass)
-  $roman = $mtr->parse('Cm9/Bb'); # iii9/bii (minor ninth with flat-two bass)
-  $roman = $mtr->parse('D sus4'); # IV sus4 (major suspended)
-  $roman = $mtr->parse('DMaj7');  # IVmaj7 (major seventh)
-  $roman = $mtr->parse('D△7');    # IV maj7 "
+  $roman = $mtr->parse('C');      # III
+  $roman = $mtr->parse('Cm9/G');  # iii9/VII (minor-nine with seven bass)
+  $roman = $mtr->parse('Cm9/Bb'); # iii9/bii (minor-nine with flat-two bass)
+  $roman = $mtr->parse('Dsus4');  # IVsus4 (suspended)
+  $roman = $mtr->parse('D sus4'); # IV sus4
+  $roman = $mtr->parse('D maj7'); # IV maj7 (major seventh)
+  $roman = $mtr->parse('DMaj7');  # IVmaj7
+  $roman = $mtr->parse('D△7');    # IVmaj7
   $roman = $mtr->parse('E7');     # V7 (dominant seventh)
-  $roman = $mtr->parse('Em7');    # v7 (minor seventh)
-  $roman = $mtr->parse('Fmin7');  # vimin7 "
+  $roman = $mtr->parse('Fmin7');  # vimin7 (minor seventh)
   $roman = $mtr->parse('G+');     # VII+ (augmented)
 
   $mtr = Music::ToRoman->new(
